@@ -25,9 +25,9 @@
 #' optimal components and variables for the sPLS Cox model.
 #' @param x.center Logical. If TRUE, the X matrix is centered to zero means (default: TRUE).
 #' @param x.scale Logical. If TRUE, the X matrix is scaled to unit variance (default: FALSE).
-#' @param remove_near_zero_variance Logical. If TRUE, near-zero variance variables are removed (default: TRUE).
+#' @param remove_near_zero_variance Logical. If TRUE, near-zero variability variables are removed (default: TRUE).
 #' @param remove_zero_variance Logical. If TRUE, zero-variance variables are removed (default: TRUE).
-#' @param toKeep.zv Character vector. Names of variables in X to retain despite near-zero variance filtering (default: NULL).
+#' @param toKeep.zv Character vector. Names of variables in X to retain despite near-zero variability filtering (default: NULL).
 #' @param remove_non_significant Logical. If TRUE, non-significant variables/components in the final Cox model
 #' are removed through forward selection (default: FALSE).
 #' @param alpha Numeric. Significance threshold (default: 0.05).
@@ -59,7 +59,7 @@
 #'   \item \code{Y_input}: Original Y matrix (or NA if not returned).
 #'   \item \code{alpha}: Significance threshold used.
 #'   \item \code{nsv}: Variables removed due to non-significance.
-#'   \item \code{nzv}: Variables removed due to near-zero variance.
+#'   \item \code{nzv}: Variables removed due to near-zero variability.
 #'   \item \code{nz_coeffvar}: Variables removed due to near-zero coefficient of variation.
 #'   \item \code{class}: Model class.
 #'   \item \code{time}: Time taken to run the analysis.
@@ -387,6 +387,10 @@ isb.splsdrcox <- function(X, Y,
 #' @param returnData Logical. Return original and normalized X and Y matrices (default: TRUE).
 #' @param PARALLEL Logical. Run the cross validation with multicore option. As many cores as your
 #' total cores - 1 will be used. It could lead to higher RAM consumption (default: FALSE).
+#' @param n_cores Numeric. Number of cores to use for parallel processing. This parameter is only
+#' used if `PARALLEL` is `TRUE`. If `NULL`, it will use all available cores minus one. Otherwise,
+#' it will use the minimum between the value specified and the total number of cores - 1. The fewer
+#' cores used, the less RAM memory will be used.(default: NULL).
 #' @param verbose Logical. If verbose = TRUE, extra messages could be displayed (default: FALSE).
 #' @param seed Number. Seed value for performing runs/folds divisions (default: 123).
 #'
@@ -438,7 +442,7 @@ cv.isb.splsdrcox <- function(X, Y,
                              pred.attr = "mean", pred.method = "cenROC", fast_mode = FALSE,
                              max.iter = 200,
                              MIN_EPV = 5, return_models = FALSE, returnData = FALSE,
-                             PARALLEL = FALSE, verbose = FALSE, seed = 123){
+                             PARALLEL = FALSE, n_cores = NULL, verbose = FALSE, seed = 123){
   # tol Numeric. Tolerance for solving: solve(t(P) %*% W) (default: 1e-15).
   tol = 1e-10
 
@@ -593,7 +597,7 @@ cv.isb.splsdrcox <- function(X, Y,
                                                      fast_mode = fast_mode, return_models = return_models,
                                                      max.iter = max.iter,
                                                      MIN_EPV = MIN_EPV, verbose = verbose,
-                                                     pred.attr = pred.attr, pred.method = pred.method, seed = seed, PARALLEL = PARALLEL, returnData = FALSE)
+                                                     pred.attr = pred.attr, pred.method = pred.method, seed = seed, PARALLEL = PARALLEL, n_cores = n_cores, returnData = FALSE)
     t2 <- Sys.time()
     time <- difftime(t2,t1,units = "mins")
     if(verbose){
