@@ -25,9 +25,9 @@
 #' optimal components and variables for the sPLS Cox model.
 #' @param x.center Logical. If TRUE, the X matrix is centered to zero means (default: TRUE).
 #' @param x.scale Logical. If TRUE, the X matrix is scaled to unit variance (default: FALSE).
-#' @param remove_near_zero_variance Logical. If TRUE, near-zero variance variables are removed (default: TRUE).
+#' @param remove_near_zero_variance Logical. If TRUE, near-zero variability variables are removed (default: TRUE).
 #' @param remove_zero_variance Logical. If TRUE, zero-variance variables are removed (default: TRUE).
-#' @param toKeep.zv Character vector. Names of variables in X to retain despite near-zero variance filtering (default: NULL).
+#' @param toKeep.zv Character vector. Names of variables in X to retain despite near-zero variability filtering (default: NULL).
 #' @param remove_non_significant Logical. If TRUE, non-significant variables/components in the final Cox model
 #' are removed through forward selection (default: FALSE).
 #' @param alpha Numeric. Significance threshold (default: 0.05).
@@ -59,7 +59,7 @@
 #'   \item \code{Y_input}: Original Y matrix (or NA if not returned).
 #'   \item \code{alpha}: Significance threshold used.
 #'   \item \code{nsv}: Variables removed due to non-significance.
-#'   \item \code{nzv}: Variables removed due to near-zero variance.
+#'   \item \code{nzv}: Variables removed due to near-zero variability.
 #'   \item \code{nz_coeffvar}: Variables removed due to near-zero coefficient of variation.
 #'   \item \code{class}: Model class.
 #'   \item \code{time}: Time taken to run the analysis.
@@ -379,6 +379,10 @@ isb.splsicox <- function(X, Y,
 #' @param returnData Logical. Return original and normalized X and Y matrices (default: TRUE).
 #' @param PARALLEL Logical. Run the cross validation with multicore option. As many cores as your
 #' total cores - 1 will be used. It could lead to higher RAM consumption (default: FALSE).
+#' @param n_cores Numeric. Number of cores to use for parallel processing. This parameter is only
+#' used if `PARALLEL` is `TRUE`. If `NULL`, it will use all available cores minus one. Otherwise,
+#' it will use the minimum between the value specified and the total number of cores - 1. The fewer
+#' cores used, the less RAM memory will be used.(default: NULL).
 #' @param verbose Logical. If verbose = TRUE, extra messages could be displayed (default: FALSE).
 #' @param seed Number. Seed value for performing runs/folds divisions (default: 123).
 #'
@@ -411,19 +415,19 @@ isb.splsicox <- function(X, Y,
 #' n_run = 1, k_folds = 2, x.center = TRUE, x.scale = TRUE)
 
 cv.isb.splsicox <- function(X, Y,
-                                     max.ncomp = 8, penalty.list = seq(0,0.9,0.1),
-                                     n_run = 3, k_folds = 10,
-                                     x.center = TRUE, x.scale = FALSE,
-                                     remove_near_zero_variance = TRUE, remove_zero_variance = TRUE, toKeep.zv = NULL,
-                                     remove_variance_at_fold_level = FALSE,
-                                     remove_non_significant_models = FALSE, remove_non_significant = FALSE,
-                                     alpha = 0.05,
-                                     w_AIC = 0, w_C.Index = 0, w_AUC = 1, w_I.BRIER = 0, times = NULL,
-                                      max_time_points = 15,
-                                      MIN_AUC_INCREASE = 0.01, MIN_AUC = 0.8, MIN_COMP_TO_CHECK = 3,
-                                     pred.attr = "mean", pred.method = "cenROC", fast_mode = FALSE,
-                                     MIN_EPV = 5, return_models = FALSE, returnData = FALSE,
-                                     PARALLEL = FALSE, verbose = FALSE, seed = 123){
+                            max.ncomp = 8, penalty.list = seq(0,0.9,0.1),
+                            n_run = 3, k_folds = 10,
+                            x.center = TRUE, x.scale = FALSE,
+                            remove_near_zero_variance = TRUE, remove_zero_variance = TRUE, toKeep.zv = NULL,
+                            remove_variance_at_fold_level = FALSE,
+                            remove_non_significant_models = FALSE, remove_non_significant = FALSE,
+                            alpha = 0.05,
+                            w_AIC = 0, w_C.Index = 0, w_AUC = 1, w_I.BRIER = 0, times = NULL,
+                            max_time_points = 15,
+                            MIN_AUC_INCREASE = 0.01, MIN_AUC = 0.8, MIN_COMP_TO_CHECK = 3,
+                            pred.attr = "mean", pred.method = "cenROC", fast_mode = FALSE,
+                            MIN_EPV = 5, return_models = FALSE, returnData = FALSE,
+                            PARALLEL = FALSE, n_cores = NULL, verbose = FALSE, seed = 123){
   # tol Numeric. Tolerance for solving: solve(t(P) %*% W) (default: 1e-15).
   tol = 1e-10
 
@@ -561,7 +565,7 @@ cv.isb.splsicox <- function(X, Y,
                                        remove_non_significant = remove_non_significant,
                                        fast_mode = fast_mode, return_models = return_models,
                                        MIN_EPV = MIN_EPV, verbose = verbose,
-                                       pred.attr = pred.attr, pred.method = pred.method, seed = seed, PARALLEL = PARALLEL, returnData = FALSE)
+                                       pred.attr = pred.attr, pred.method = pred.method, seed = seed, PARALLEL = PARALLEL, n_cores = n_cores, returnData = FALSE)
     t2 <- Sys.time()
     time <- difftime(t2,t1,units = "mins")
     if(verbose){
