@@ -120,10 +120,16 @@
 #'
 #' \code{Y_input}: Y input matrix
 #'
+#' \code{design}: Design used for the strength of the relationship to be modeled between blocks.
+#'
 #' \code{B.hat}: PLS beta matrix
 #'
 #' \code{R2}: sPLS acumulate R2
 #'
+#' \code{alpha}: Significance threshold used.
+#'
+#' \code{nsv}: Variables removed due to non-significance.
+#'
 #' \code{nzv}: Variables removed by remove_near_zero_variance or remove_zero_variance.
 #'
 #' \code{nz_coeffvar}: Variables removed by coefficient variation near zero.
@@ -275,7 +281,7 @@ mb.splsdacox <- function (X, Y,
   if(is.null(vector)){
     lst_BV <- getBestVectorMB(Xh = Xh, DR_coxph = DR_coxph, Yh = Yh, n.comp = n.comp, max.iter = max.iter, vector = vector,
                               MIN_AUC_INCREASE = MIN_AUC_INCREASE, MIN_NVAR = MIN_NVAR, MAX_NVAR = MAX_NVAR, cut_points = n.cut_points,
-                              EVAL_METHOD = EVAL_METHOD, EVAL_EVALUATOR = pred.method, PARALLEL = FALSE, mode = "splsda", times = times,
+                              EVAL_METHOD = EVAL_METHOD, EVAL_EVALUATOR = pred.method, PARALLEL = FALSE, n_cores = NULL, mode = "splsda", times = times,
                               max_time_points = max_time_points, verbose = verbose)
     keepX <- lst_BV$best.keepX
     plotVAR <- plot_VAR_eval(lst_BV, EVAL_METHOD = EVAL_METHOD)
@@ -301,7 +307,7 @@ mb.splsdacox <- function (X, Y,
         message("Vector does not has the proper structure. Optimizing best n.variables by using your vector as start vector.")
         lst_BV <- getBestVectorMB(Xh = Xh, DR_coxph = DR_coxph, Yh = Yh, n.comp = n.comp, max.iter = max.iter, vector = vector,
                                   MIN_AUC_INCREASE = MIN_AUC_INCREASE, MIN_NVAR = MIN_NVAR, MAX_NVAR = MAX_NVAR, cut_points = n.cut_points,
-                                  EVAL_METHOD = EVAL_METHOD, EVAL_EVALUATOR = pred.method, PARALLEL = FALSE, mode = "splsda", times = times,
+                                  EVAL_METHOD = EVAL_METHOD, EVAL_EVALUATOR = pred.method, PARALLEL = FALSE, n_cores = NULL, mode = "splsda", times = times,
                                   max_time_points = max_time_points, verbose = verbose)
         keepX <- lst_BV$best.keepX
         plotVAR <- plot_VAR_eval(lst_BV, EVAL_METHOD = EVAL_METHOD)
@@ -571,6 +577,7 @@ mb.splsdacox <- function (X, Y,
                                  call = if(returnData) func_call else NA,
                                  X_input = if(returnData) X_original else NA,
                                  Y_input = if(returnData) Y_original else NA,
+                                 design = design,
                                  B.hat = B.hat,
                                  R2 = R2,
                                  # SCR = SCR,
@@ -690,6 +697,10 @@ mb.splsdacox <- function (X, Y,
 #' @param returnData Logical. Return original and normalized X and Y matrices (default: TRUE).
 #' @param PARALLEL Logical. Run the cross validation with multicore option. As many cores as your
 #' total cores - 1 will be used. It could lead to higher RAM consumption (default: FALSE).
+#' @param n_cores Numeric. Number of cores to use for parallel processing. This parameter is only
+#' used if `PARALLEL` is `TRUE`. If `NULL`, it will use all available cores minus one. Otherwise,
+#' it will use the minimum between the value specified and the total number of cores - 1. The fewer
+#' cores used, the less RAM memory will be used.(default: NULL).
 #' @param verbose Logical. If verbose = TRUE, extra messages could be displayed (default: FALSE).
 #' @param seed Number. Seed value for performing runs/folds divisions (default: 123).
 #'
@@ -705,7 +716,7 @@ mb.splsdacox <- function (X, Y,
 #'
 #' \code{opt.comp}: Optimal component selected by the best_model.
 #' \code{opt.nvar}: Optimal number of variables selected by the best_model.
-#' \code{design}: Design matrix used for computing the MultiBlocks models.
+#' \code{design}: Design used for the strength of the relationship to be modeled between blocks.
 #'
 #' \code{plot_AIC}: AIC plot by each hyper-parameter.
 #' \code{plot_C.Index}: C-Index plot by each hyper-parameter.
@@ -752,7 +763,7 @@ cv.mb.splsdacox <- function(X, Y,
                             MIN_AUC_INCREASE = 0.01, MIN_AUC = 0.8, MIN_COMP_TO_CHECK = 3,
                             pred.attr = "mean", pred.method = "cenROC", max.iter= 200, fast_mode = FALSE,
                             MIN_EPV = 5, return_models = FALSE, returnData = FALSE,
-                            PARALLEL = FALSE, verbose = FALSE, seed = 123){
+                            PARALLEL = FALSE, n_cores = NULL, verbose = FALSE, seed = 123){
   # tol Numeric. Tolerance for solving: solve(t(P) %*% W) (default: 1e-15).
   tol = 1e-10
 
@@ -894,7 +905,7 @@ cv.mb.splsdacox <- function(X, Y,
                                          remove_non_significant = remove_non_significant, tol = tol,
                                          max.iter = max.iter, times = times, pred.method = pred.method, max_time_points = max_time_points,
                                          returnData = returnData, total_models = total_models,
-                                         PARALLEL = PARALLEL, verbose = verbose)
+                                         PARALLEL = PARALLEL, n_cores = n_cores, verbose = verbose)
 
   # already check in Coxmos_models
   # if(all(is.na(unlist(lst_model)))){
@@ -946,7 +957,7 @@ cv.mb.splsdacox <- function(X, Y,
       times <- getTimesVector(Y, max_time_points = max_time_points)
     }
 
-    #As we are measuring just one evaluator and one method - PARALLEL = FALSE
+    #As we are measuring just one evaluator and one method - PARALLEL = FALSE, n_cores = NULL
     lst_df <- get_COX_evaluation_BRIER(comp_model_lst = comp_model_lst,
                                        fast_mode = fast_mode,
                                        X_test = X, Y_test = Y,
@@ -955,7 +966,7 @@ cv.mb.splsdacox <- function(X, Y,
                                        pred.method = pred.method, pred.attr = pred.attr,
                                        max.ncomp = max.ncomp, n_run = n_run, k_folds = k_folds,
                                        MIN_AUC_INCREASE = MIN_AUC_INCREASE, MIN_AUC = MIN_AUC, MIN_COMP_TO_CHECK = MIN_COMP_TO_CHECK,
-                                       w_I.BRIER = w_I.BRIER, method.train = pkg.env$mb.splsdacox, PARALLEL = FALSE, verbose = verbose)
+                                       w_I.BRIER = w_I.BRIER, method.train = pkg.env$mb.splsdacox, PARALLEL = FALSE, n_cores = NULL, verbose = verbose)
 
     df_results_evals_comp <- lst_df$df_results_evals_comp
     df_results_evals_run <- lst_df$df_results_evals_run
@@ -982,7 +993,7 @@ cv.mb.splsdacox <- function(X, Y,
                                      fast_mode = fast_mode, pred.method = pred.method, pred.attr = pred.attr,
                                      max.ncomp = max.ncomp, n_run = n_run, k_folds = k_folds,
                                      MIN_AUC_INCREASE = MIN_AUC_INCREASE, MIN_AUC = MIN_AUC, MIN_COMP_TO_CHECK = MIN_COMP_TO_CHECK,
-                                     w_AUC = w_AUC, method.train = pkg.env$mb.splsdacox, PARALLEL = FALSE, verbose = verbose)
+                                     w_AUC = w_AUC, method.train = pkg.env$mb.splsdacox, PARALLEL = FALSE, n_cores = NULL, verbose = verbose)
 
     if(is.null(df_results_evals_comp)){
       df_results_evals_comp <- lst_df$df_results_evals_comp
