@@ -310,7 +310,7 @@ splsdrcox <- function(X, Y,
   if(is.null(vector)){
     lst_BV <- getBestVector(Xh = Xh, DR_coxph = DR_coxph, Yh = Yh, n.comp = n.comp, max.iter = max.iter, vector = vector,
                             MIN_AUC_INCREASE = MIN_AUC_INCREASE, MIN_NVAR = MIN_NVAR, MAX_NVAR = MAX_NVAR, cut_points = n.cut_points,
-                            EVAL_METHOD = EVAL_METHOD, EVAL_EVALUATOR = pred.method, PARALLEL = FALSE, mode = "spls", times = times,
+                            EVAL_METHOD = EVAL_METHOD, EVAL_EVALUATOR = pred.method, PARALLEL = FALSE, n_cores = NULL, mode = "spls", times = times,
                             max_time_points = max_time_points, verbose = verbose)
     keepX <- lst_BV$best.keepX
     plotVAR <- plot_VAR_eval(lst_BV, EVAL_METHOD = EVAL_METHOD)
@@ -329,7 +329,7 @@ splsdrcox <- function(X, Y,
     }else{
       message("Vector does not has the proper structure. Optimizing best n.variables by using your vector as start vector.")
       lst_BV <- getBestVector(Xh, DR_coxph, Yh, n.comp, max.iter, vector = NULL, MIN_AUC_INCREASE, MIN_NVAR = MIN_NVAR, MAX_NVAR = MAX_NVAR, cut_points = n.cut_points,
-                              EVAL_METHOD = EVAL_METHOD, EVAL_EVALUATOR = pred.method, PARALLEL = FALSE, mode = "spls", times = times, max_time_points = max_time_points, verbose = verbose)
+                              EVAL_METHOD = EVAL_METHOD, EVAL_EVALUATOR = pred.method, PARALLEL = FALSE, n_cores = NULL, mode = "spls", times = times, max_time_points = max_time_points, verbose = verbose)
       keepX <- lst_BV$best.keepX
       plotVAR <- plot_VAR_eval(lst_BV, EVAL_METHOD = EVAL_METHOD)
     }
@@ -686,6 +686,10 @@ splsdrcox <- function(X, Y,
 #' @param returnData Logical. Return original and normalized X and Y matrices (default: TRUE).
 #' @param PARALLEL Logical. Run the cross validation with multicore option. As many cores as your
 #' total cores - 1 will be used. It could lead to higher RAM consumption (default: FALSE).
+#' @param n_cores Numeric. Number of cores to use for parallel processing. This parameter is only
+#' used if `PARALLEL` is `TRUE`. If `NULL`, it will use all available cores minus one. Otherwise,
+#' it will use the minimum between the value specified and the total number of cores - 1. The fewer
+#' cores used, the less RAM memory will be used.(default: NULL).
 #' @param verbose Logical. If verbose = TRUE, extra messages could be displayed (default: FALSE).
 #' @param seed Number. Seed value for performing runs/folds divisions (default: 123).
 #'
@@ -747,7 +751,7 @@ cv.splsdrcox <- function(X, Y,
                         pred.attr = "mean", pred.method = "cenROC", fast_mode = FALSE,
                         max.iter = 200,
                         MIN_EPV = 5, return_models = FALSE, returnData = FALSE,
-                        PARALLEL = FALSE, verbose = FALSE, seed = 123){
+                        PARALLEL = FALSE, n_cores = NULL, verbose = FALSE, seed = 123){
   # tol Numeric. Tolerance for solving: solve(t(P) %*% W) (default: 1e-15).
   tol = 1e-10
 
@@ -886,7 +890,7 @@ cv.splsdrcox <- function(X, Y,
                                           remove_non_significant = remove_non_significant, tol = tol,
                                           max.iter = max.iter, times = times, pred.method = pred.method, max_time_points = max_time_points,
                                           returnData = returnData, total_models = total_models,
-                                          PARALLEL = PARALLEL, verbose = verbose)
+                                          PARALLEL = PARALLEL, n_cores = n_cores, verbose = verbose)
 
   if(all(is.null(comp_model_lst))){
     message(paste0("Best model could NOT be obtained. All models computed present problems. Try to remove variance at fold level. If problem persists, try to delete manually some problematic variables."))
@@ -938,7 +942,7 @@ cv.splsdrcox <- function(X, Y,
       times <- getTimesVector(Y, max_time_points = max_time_points)
     }
 
-    #As we are measuring just one evaluator and one method - PARALLEL = FALSE
+    #As we are measuring just one evaluator and one method - PARALLEL = FALSE, n_cores = NULL
     lst_df <- get_COX_evaluation_BRIER(comp_model_lst = comp_model_lst,
                                        fast_mode = fast_mode,
                                        X_test = X, Y_test = Y,
@@ -947,7 +951,7 @@ cv.splsdrcox <- function(X, Y,
                                        pred.method = pred.method, pred.attr = pred.attr,
                                        max.ncomp = max.ncomp, n_run = n_run, k_folds = k_folds,
                                        MIN_AUC_INCREASE = MIN_AUC_INCREASE, MIN_AUC = MIN_AUC, MIN_COMP_TO_CHECK = MIN_COMP_TO_CHECK,
-                                       w_I.BRIER = w_I.BRIER, method.train = pkg.env$splsdrcox_dynamic, PARALLEL = FALSE, verbose = verbose)
+                                       w_I.BRIER = w_I.BRIER, method.train = pkg.env$splsdrcox_dynamic, PARALLEL = FALSE, n_cores = NULL, verbose = verbose)
 
     df_results_evals_comp <- lst_df$df_results_evals_comp
     df_results_evals_run <- lst_df$df_results_evals_run
@@ -967,7 +971,7 @@ cv.splsdrcox <- function(X, Y,
       times <- getTimesVector(Y, max_time_points = max_time_points)
     }
 
-    #As we are measuring just one evaluator and one method - PARALLEL = FALSE
+    #As we are measuring just one evaluator and one method - PARALLEL = FALSE, n_cores = NULL
     lst_df <- get_COX_evaluation_AUC(comp_model_lst = comp_model_lst,
                                      X_test = X, Y_test = Y,
                                      lst_X_test = lst_test_indexes, lst_Y_test = lst_test_indexes,
@@ -975,7 +979,7 @@ cv.splsdrcox <- function(X, Y,
                                      fast_mode = fast_mode, pred.method = pred.method, pred.attr = pred.attr,
                                      max.ncomp = max.ncomp, n_run = n_run, k_folds = k_folds,
                                      MIN_AUC_INCREASE = MIN_AUC_INCREASE, MIN_AUC = MIN_AUC, MIN_COMP_TO_CHECK = MIN_COMP_TO_CHECK,
-                                     w_AUC = w_AUC, method.train = pkg.env$splsdrcox_dynamic, PARALLEL = FALSE, verbose = verbose)
+                                     w_AUC = w_AUC, method.train = pkg.env$splsdrcox_dynamic, PARALLEL = FALSE, n_cores = NULL, verbose = verbose)
 
     if(is.null(df_results_evals_comp)){
       df_results_evals_comp <- lst_df$df_results_evals_comp
